<template>
  <div>
    <el-upload :action="uploadUrl" :show-file-list="true" :limit="uploadNum" :accept="acceptList" multiple
      :file-list="fileUrl" :on-remove="handleRemove" :before-remove="beforeRemove" :on-success="handleUploadSuccess"
      :before-upload="beforeUpload">
      <el-button size="small" type="primary">点击上传</el-button>
      <div slot="tip" class="el-upload__tip">只能上传pdf、mp4、avi、png、jpg、jpge、flv文件，且不超过{{ fileSizeLimitM }}G</div>
      <div v-if="fileUrl && fileUrl.length > 0 && uploadNum === 1">
        <video controls class="returnShow" v-if="fileType === 'video' && fileUrl[0]" :src="'/api/files/' + fileUrl[0].url"></video>
        <img class="returnShow" v-if="fileType === 'img' && fileUrl[0]" :src="'/api/files/' + fileUrl[0].url" />
      </div>
    </el-upload>
  </div>
</template>

<script>

export default {
  name: "UploadC",
  props: {
    uploadNum: {
      required: false,
      default: 1,
      type: Number
    },
    fileType: {
      required: false,
      type: String
    },
    fileSizeLimitM: {
      required: false,
      default: 1,
      type: Number
    },
    fileUrl: {
      type: Array,
      required: true,
      default: () => []
    }
  },
  data() {
    return {
      uploadUrl: "/api/upload/upload",
      fileTypeList: {
        'video': ['mp4', 'avi', 'flv'],
        'img': ['jpg', 'png', 'jpeg'],
        'pdf': ['pdf'],
        'file': ['doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx', 'txt', 'png', 'jpg', 'jpeg', 'pdf'],
      }
    };
  },
  methods: {
    clearFile() {
      this.fileUrl = [];
    },
    beforeRemove(file, fileList) {
      if (file && file.status === "success") {
        return this.$confirm(`确定移除 ${file.name}？`);
      }
    },
    handleRemove(file, fileList) {
      this.$emit('removeFile', this.fileUrl, file.name);
    },
    handleUploadSuccess(res, file) {
      if (res.response) {
        this.fileUrl.push(res.response);
        console.log("当前文件信息", res.response)
        this.$emit('getUploadUrl', this.fileUrl);
      }
    },
    beforeUpload(file) {
      const { type } = file;
      const typeList = this.fileTypeList[this.fileType];
      let limitType = true;
      if (typeList) {
        const tempType = typeList.find(item => {
          if (type.includes(item) || file.name.endsWith(".flv")) {
            return true;
          } else {
            return false;
          }
        });
        if (!tempType) {
          this.$message.error(`请上传正确的文件格式！`);
          limitType = false;
        }
      }
      const limit = file.size / 1024 / 1024 / 1024 < this.fileSizeLimitM;
      if (!limit) {
        this.$message.error(`上传文件大小不能超过 ${this.fileSizeLimitM}G!`);
      }
      return limitType && limit;
    },
  },
  computed: {
    acceptList() {
      let temp = '.*';
      if (this.fileTypeList[this.fileType]) {
        temp = this.fileTypeList[this.fileType].map(item => '.' + item).join(',');
      }
      return temp;
    }
  }
};
</script>

<style scoped>
.returnShow {
  width: 300px;
  height: 200px;
}

.avatar-uploader {
  text-align: center;
  width: 100%
}

.avatar-uploader-icon:hover {
  border-color: #409EFF;
}

.avatar-uploader-icon {
  font-size: 28px;
  color: #8c939d;
  text-align: center;
  border: 1px dashed #d9d9d9;
  border-radius: 6px;
  cursor: pointer;

}

.avatar {
  display: block;
}
</style>
